@@ -4,15 +4,35 @@ from typing import Dict
 
 class Post:
 
-    def __init__(self, title, subtitle, user_id):
+    def __init__(self, title: str, subtitle: str, user_id,
+                 audience: str = None,
+                 write_comment_permissions: str = None):
+        """
+
+        Args:
+            title:
+            subtitle:
+            user_id:
+            audience: possible values: everyone, only_paid, founding, only_free
+            write_comment_permissions: none, only_paid, everyone (this field is a mess)
+        """
         self.draft_title = title
         self.draft_subtitle = subtitle
         self.draft_body = {"type": "doc", "content": []}
         self.draft_bylines = [{"id": int(user_id), "is_guest": False}]
+        self.audience = audience if audience is not None else "everyone"
+
+        # TODO better understand the possible values and combinations with audience
+        if write_comment_permissions is not None:
+            self.write_comment_permissions = write_comment_permissions
+        else:
+            self.write_comment_permissions = self.audience
 
     def add(self, item: Dict):
         """
 
+        Add item to draft body.
+
         Args:
             item:
 
@@ -40,12 +60,30 @@ class Post:
         return self
 
     def paragraph(self, content=None):
+        """
+
+        Args:
+            content:
+
+        Returns:
+
+        """
         item = {"type": "paragraph"}
         if content is not None:
             item["content"] = content
         return self.add(item)
 
-    def heading(self, content=None, level=1):
+    def heading(self, content=None, level: int = 1):
+        """
+
+        Args:
+            content:
+            level:
+
+        Returns:
+
+        """
+
         item = {"type": "heading"}
         if content is not None:
             item["content"] = content
@@ -53,9 +91,22 @@ class Post:
         return self.add(item)
 
     def horizontal_rule(self):
+        """
+
+        Returns:
+
+        """
         return self.add({"type": "horizontal_rule"})
 
     def attrs(self, level):
+        """
+
+        Args:
+            level:
+
+        Returns:
+
+        """
         content_attrs = self.draft_body["content"][-1].get("attrs", {})
         content_attrs.update({"level": level})
         self.draft_body["content"][-1]["attrs"] = content_attrs
@@ -116,7 +167,7 @@ class Post:
         self.draft_body["content"][-1]["content"] = content
         return self
 
-    def text(self, value):
+    def text(self, value: str):
         """
 
         Add text to the last paragraph.
@@ -133,6 +184,11 @@ class Post:
         return self
 
     def add_complex_text(self, text):
+        """
+
+        Args:
+            text:
+        """
         if isinstance(text, str):
             self.text(text)
         else:
@@ -141,6 +197,14 @@ class Post:
                     self.text(chunk.get("content")).marks(chunk.get("marks"))
 
     def marks(self, marks):
+        """
+
+        Args:
+            marks:
+
+        Returns:
+
+        """
         content = self.draft_body["content"][-1].get("content", [])[-1]
         content_marks = content.get("marks", [])
         for mark in marks:
@@ -155,14 +219,30 @@ class Post:
         return self
 
     def remove_last_paragraph(self):
+        """
+
+        """
         del self.draft_body.get("content")[-1]
 
     def get_draft(self):
+        """
+
+        Returns:
+
+        """
         out = vars(self)
         out["draft_body"] = json.dumps(out["draft_body"])
         return out
 
-    def subscribe_with_caption(self, value):
+    def subscribe_with_caption(self, value: str):
+        """
+
+        Args:
+            value:
+
+        Returns:
+
+        """
         content = self.draft_body["content"][-1].get("content", [])
         content += [{"type": "subscribeWidget",
                      "attrs": {"url": "%%checkout_url%%", "text": "Subscribe"},
@@ -177,7 +257,15 @@ class Post:
         self.draft_body["content"][-1]["content"] = content
         return self
 
-    def youtube(self, value):
+    def youtube(self, value: str):
+        """
+
+        Args:
+            value:
+
+        Returns:
+
+        """
         content_attrs = self.draft_body["content"][-1].get("attrs", {})
         content_attrs.update({"videoId": value})
         self.draft_body["content"][-1]["attrs"] = content_attrs
